``cfd`` — Plotting
===================

.. module:: pycohortflow.cfd

This module contains the main public function for creating cohort flow
diagrams.

Main Function
-------------

.. autofunction:: plot_cohort_flow_diagram
